@@ -6,4 +6,6 @@
 #' @title Global Variables Declaration
 #' @keywords internal
 utils::globalVariables(c("motif", "start", "ID", "length", "seq_order", "end", "name", 
-                         "class", "class.x", "support", "x", "y", "yend", "Group","frequency"))
+                         "class", "class.x", "support", "x", "y", "yend", "Group","frequency",
+                         "element", "value"
+                         ))
